@@ -3,6 +3,7 @@ use Moose;
 extends 'Bing::Search::Result';
 
 with 'Bing::Search::Role::Types::UrlType';
+with 'Bing::Search::Role::Types::DateType';
 
 with qw(
    Bing::Search::Role::Result::Url
@@ -11,6 +12,7 @@ with qw(
    Bing::Search::Role::Result::Description
    Bing::Search::Role::Result::DisplayUrl
    Bing::Search::Role::Result::Title
+   Bing::Search::Role::Result::Total
 );
 
 __PACKAGE__->meta->make_immutable;
